/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.support.management.observation;

import io.micrometer.common.KeyValues;

/**
 * A default {@link MessageReceiverObservationConvention} implementation.
 * Provides low cardinalities as a {@link IntegrationObservation.HandlerTags} values.
 *
 * @author Artem Bilan
 *
 * @since 6.0
 */
public class DefaultMessageReceiverObservationConvention implements MessageReceiverObservationConvention {

	/**
	 * A shared singleton instance for {@link DefaultMessageReceiverObservationConvention}.
	 */
	public static final DefaultMessageReceiverObservationConvention INSTANCE =
			new DefaultMessageReceiverObservationConvention();

	@Override
	public KeyValues getLowCardinalityKeyValues(MessageReceiverContext context) {
		return KeyValues.of(
				IntegrationObservation.HandlerTags.COMPONENT_NAME.withValue(context.getHandlerName()),
				IntegrationObservation.HandlerTags.COMPONENT_TYPE.withValue("handler"));
	}

}
